exceptiontools
==============

.. automodule:: abjad.tools.exceptiontools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.exceptiontools.AssignabilityError.AssignabilityError
      ~abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError
      ~abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError
      ~abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError
      ~abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError
      ~abjad.tools.exceptiontools.ExtraSpannerError.ExtraSpannerError
      ~abjad.tools.exceptiontools.ImpreciseTempoError.ImpreciseTempoError
      ~abjad.tools.exceptiontools.InstrumentError.InstrumentError
      ~abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError
      ~abjad.tools.exceptiontools.MissingInstrumentError.MissingInstrumentError
      ~abjad.tools.exceptiontools.MissingMarkError.MissingMarkError
      ~abjad.tools.exceptiontools.MissingMeasureError.MissingMeasureError
      ~abjad.tools.exceptiontools.MissingNamedComponentError.MissingNamedComponentError
      ~abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError
      ~abjad.tools.exceptiontools.MissingPitchError.MissingPitchError
      ~abjad.tools.exceptiontools.MissingSpannerError.MissingSpannerError
      ~abjad.tools.exceptiontools.MissingTempoError.MissingTempoError
      ~abjad.tools.exceptiontools.OverfullContainerError.OverfullContainerError
      ~abjad.tools.exceptiontools.PartitionError.PartitionError
      ~abjad.tools.exceptiontools.SchemeParserFinishedException.SchemeParserFinishedException
      ~abjad.tools.exceptiontools.SpannerPopulationError.SpannerPopulationError
      ~abjad.tools.exceptiontools.TempoError.TempoError
      ~abjad.tools.exceptiontools.TieChainError.TieChainError
      ~abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError
      ~abjad.tools.exceptiontools.TonalHarmonyError.TonalHarmonyError
      ~abjad.tools.exceptiontools.TupletFuseError.TupletFuseError
      ~abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError
      ~abjad.tools.exceptiontools.UnderfullContainerError.UnderfullContainerError
